# datasmryzr

<!-- [![PyPI - Version](https://img.shields.io/pypi/v/datasmryzr.svg)](https://pypi.org/project/datasmryzr)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/datasmryzr.svg)](https://pypi.org/project/datasmryzr) -->

![Python package](https://github.com/kristyhoran/datasmryzr/actions/workflows/python-package.yml/badge.svg)

-----

Datasmryzr is a small tool that is designed to collate and render pathogen genomics analysis results, such as trees, tables and matrices as a `.html` for sharing and interrogation. 

## Table of Contents

- [Installation](#installation)
- [Usage](#usage)
- [License](#license)

## Installation

```console
pip install datasmryzr
```
## Usage 


## License

`datasmryzr` is distributed under the terms of the [MIT](https://spdx.org/licenses/MIT.html) license.
